##  Workspace Access Options
Users can access a workspace in different ways:
  * Direct URL including the workspace name
  * Base URL to a region or domain
  * Workspace chooser by appending /workspace-selection to base URL

![Flowchart showing three ways to access SAP LeanIX workspaces: direct URL, base URL, or workspace chooser.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio4292185183894485ac5cb9ae8dbe95d7_HiRes.png)
